@@ -10,7 +10,7 @@ use String::ShellQuote;
 
 use base 'Exporter';
 our ( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
-our $VERSION = '0.060'; # VERSION
+our $VERSION = '0.062'; # VERSION
 
 @EXPORT      = qw();
 %EXPORT_TAGS = ();
@@ -108,8 +108,10 @@ sub sys_fmt {
       $cmd .= shell_quote(@$e) . " ";
     } elsif ( $e =~ /^>>|\d?>|<|<<|\||\d?>\&\d$/ ) {
       $cmd .= $e . " ";
-    } else {
+    } elsif(defined $e) {
       $cmd .= shell_quote($e) . " ";
+    } else {
+      next;
     }
   }
   chomp $cmd;
